@@ -1,10 +1,12 @@
+
 require 5;
 package Pod::Simple::PullParser;
-$VERSION = '2.29_4';
+$VERSION = '2.01';
 use Pod::Simple ();
 BEGIN {@ISA = ('Pod::Simple')}
 
 use strict;
+use utf8;
 use Carp ();
 
 use Pod::Simple::PullParserStartToken;
@@ -121,7 +123,6 @@ sub get_token {
       # Read those many lines at a time
       for(my $i = Pod::Simple::MANY_LINES; $i--;) {
         DEBUG > 3 and print " Fetching a line from source filehandle $fh...\n";
-        local $/ = $Pod::Simple::NL;
         push @lines, scalar(<$fh>); # readline
         DEBUG > 3 and print "  Line is: ",
           defined($lines[-1]) ? $lines[-1] : "<undef>\n";
@@ -204,6 +205,7 @@ sub get_token {
   return shift @{$self->{'token_buffer'}}; # that's an undef if empty
 }
 
+use UNIVERSAL ();
 sub unget_token {
   my $self = shift;
   DEBUG and print "Ungetting ", scalar(@_), " tokens: ",
@@ -230,8 +232,6 @@ sub unget_token {
 sub set_source {
   my $self = shift @_;
   return $self->{'source_fh'} unless @_;
-  Carp::croak("Cannot assign new source to pull parser; create a new instance, instead")
-      if $self->{'source_fh'} || $self->{'source_scalar_ref'} || $self->{'source_arrayref'};
   my $handle;
   if(!defined $_[0]) {
     Carp::croak("Can't use empty-string as a source for set_source");
@@ -319,7 +319,6 @@ sub _get_titled_section {
   my $desperate_for_title  = delete $options{'desperate'};
   my $accept_verbatim      = delete $options{'accept_verbatim'};
   my $max_content_length   = delete $options{'max_content_length'};
-  my $nocase               = delete $options{'nocase'};
   $max_content_length = 120 unless defined $max_content_length;
 
   Carp::croak( "Unknown " . ((1 == keys %options) ? "option: " : "options: ")
@@ -346,7 +345,6 @@ sub _get_titled_section {
 
   my $head1_text_content;
   my $para_text_content;
-  my $skipX;
 
   while(
     ++$token_count <= ($max_token || 1_000_000)
@@ -364,17 +362,10 @@ sub _get_titled_section {
 
     elsif($state == 1) { # accumulating text until end of head1
       if( $token->is_text ) {
-          unless ($skipX) {
-            DEBUG and print "   Adding \"", $token->text, "\" to head1-content.\n";
-            $head1_text_content .= $token->text;
-          }
-      } elsif( $token->is_tagname('X') ) {
-          # We're going to want to ignore X<> stuff.
-          $skipX = $token->is_start;
-          DEBUG and print +($skipX ? 'Start' : 'End'), 'ing ignoring of X<> tag';
+        DEBUG and print "   Adding \"", $token->text, "\" to head1-content.\n";
+        $head1_text_content .= $token->text;
       } elsif( $token->is_end and $token->tagname eq 'head1' ) {
         DEBUG and print "  Found end of head1.  Considering content...\n";
-        $head1_text_content = uc $head1_text_content if $nocase;
         if($head1_text_content eq $titlename
           or $head1_text_content =~ m/\($titlename_re\)/s
           # We accept "=head1 Nomen Modularis (NAME)" for sake of i18n
@@ -398,9 +389,9 @@ sub _get_titled_section {
             ? (length($head1_text_content) <= $max_content_length) # sanity
             : 1)
         ) {
-          # Looks good; trim it
-          ($title = $head1_text_content) =~ s/\s+$//;
-          DEBUG and print "  It looks titular: \"$title\".\n\n  Using that.\n";
+          DEBUG and print "  It looks titular: \"$head1_text_content\".\n",
+            "\n  Using that.\n";
+          $title = $head1_text_content;
           last;
         } else {
           --$state;
@@ -461,7 +452,7 @@ sub _get_titled_section {
   $self->unget_token(@to_unget);
   
   if(DEBUG) {
-    if(defined $title) { print "  Returning title <$title>\n" }
+    if(defined $title) { print "  Returing title <$title>\n" }
     else { print "Returning title <>\n" }
   }
   
@@ -540,7 +531,7 @@ And elsewhere:
  package SomePodProcessor;
  use strict;
  use base qw(Pod::Simple::PullParser);
-
+ 
  sub run {
    my $self = shift;
   Token:
@@ -631,19 +622,11 @@ process the token-stream from the beginning.
 For example, suppose you have a document that starts out:
 
   =head1 NAME
-
+  
   Hoo::Boy::Wowza -- Stuff B<wow> yeah!
 
 $parser->get_title on that document will return "Hoo::Boy::Wowza --
-Stuff wow yeah!". If the document starts with:
-
-  =head1 Name
-
-  Hoo::Boy::W00t -- Stuff B<w00t> yeah!
-
-Then you'll need to pass the C<nocase> option in order to recognize "Name":
-
-  $parser->get_title(nocase => 1);
+Stuff wow yeah!".
 
 In cases where get_title can't find the title, it will return empty-string
 ("").
@@ -656,7 +639,7 @@ the title seems to be of the form "SomeModuleName -- description".
 For example, suppose you have a document that starts out:
 
   =head1 NAME
-
+  
   Hoo::Boy::Wowza -- Stuff B<wow> yeah!
 
 then $parser->get_short_title on that document will return
@@ -665,19 +648,11 @@ then $parser->get_short_title on that document will return
 But if the document starts out:
 
   =head1 NAME
-
+  
   Hooboy, stuff B<wow> yeah!
 
 then $parser->get_short_title on that document will return "Hooboy,
-stuff wow yeah!". If the document starts with:
-
-  =head1 Name
-
-  Hoo::Boy::W00t -- Stuff B<w00t> yeah!
-
-Then you'll need to pass the C<nocase> option in order to recognize "Name":
-
-  $parser->get_short_title(nocase => 1);
+stuff wow yeah!".
 
 If the title can't be found, then get_short_title returns empty-string
 ("").
@@ -686,30 +661,22 @@ If the title can't be found, then get_short_title returns empty-string
 
 This works like get_title except that it returns the contents of the
 "=head1 AUTHOR\n\nParagraph...\n" section, assuming that that section
-isn't terribly long. To recognize a "=head1 Author\n\nParagraph\n"
-section, pass the C<nocase> option:
-
-  $parser->get_author(nocase => 1);
+isn't terribly long.
 
 (This method tolerates "AUTHORS" instead of "AUTHOR" too.)
 
 =item $description_name = $parser->get_description
 
 This works like get_title except that it returns the contents of the
-"=head1 DESCRIPTION\n\nParagraph...\n" section, assuming that that section
-isn't terribly long. To recognize a "=head1 Description\n\nParagraph\n"
-section, pass the C<nocase> option:
-
-  $parser->get_description(nocase => 1);
+"=head1 PARAGRAPH\n\nParagraph...\n" section, assuming that that section
+isn't terribly long.
 
 =item $version_block = $parser->get_version
 
 This works like get_title except that it returns the contents of
 the "=head1 VERSION\n\n[BIG BLOCK]\n" block.  Note that this does NOT
-return the module's C<$VERSION>!! To recognize a
-"=head1 Version\n\n[BIG BLOCK]\n" section, pass the C<nocase> option:
+return the module's C<$VERSION>!!
 
-  $parser->get_version(nocase => 1);
 
 =back
 
@@ -735,22 +702,9 @@ L<Pod::Simple::PullParserEndToken>.
 
 L<HTML::TokeParser>, which inspired this.
 
-=head1 SUPPORT
-
-Questions or discussion about POD and Pod::Simple should be sent to the
-pod-people@perl.org mail list. Send an empty email to
-pod-people-subscribe@perl.org to subscribe.
-
-This module is managed in an open GitHub repository,
-L<https://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/theory/pod-simple.git> and send patches!
-
-Patches against Pod::Simple are welcome. Please send bug reports to
-<bug-pod-simple@rt.cpan.org>.
-
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -761,23 +715,12 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Pod::Simple was created by Sean M. Burke <sburke@cpan.org>.
-But don't bother him, he's retired.
-
-Pod::Simple is maintained by:
-
-=over
-
-=item * Allison Randal C<allison@perl.org>
-
-=item * Hans Dieter Pearcey C<hdp@cpan.org>
-
-=item * David E. Wheeler C<dwheeler@cpan.org>
-
-=back
+Sean M. Burke C<sburke@cpan.org>
 
 =cut
 
+
+
 JUNK:
 
 sub _old_get_title {  # some witchery in here
@@ -842,7 +785,7 @@ sub _old_get_title {  # some witchery in here
   $self->unget_token(@to_unget);
   
   if(DEBUG) {
-    if(defined $title) { print "  Returning title <$title>\n" }
+    if(defined $title) { print "  Returing title <$title>\n" }
     else { print "Returning title <>\n" }
   }
   
